==> arrow-docs-0.7.3-sources.jar: arrow/optics/Account$$optics.kt <==
package `arrow`.`optics`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `arrow`.`optics`.`Account`.Companion.iso: arrow.optics.Iso<`arrow`.`optics`.`Account`, arrow.core.Tuple2<`kotlin`.`Int`, `kotlin`.`Int`>> inline get()= arrow.optics.Iso(
  get = { account: `arrow`.`optics`.`Account` -> arrow.core.Tuple2(account.`balance`, account.`available`) },
  reverseGet = { tuple: arrow.core.Tuple2<`kotlin`.`Int`, `kotlin`.`Int`> -> `arrow`.`optics`.`Account`(tuple.a, tuple.b) }
)

inline val `arrow`.`optics`.`Account`.Companion.balance: arrow.optics.Lens<`arrow`.`optics`.`Account`, `kotlin`.`Int`> inline get()= arrow.optics.Lens(
  get = { account: `arrow`.`optics`.`Account` -> account.`balance` },
  set = { value: `kotlin`.`Int` ->
    { account: `arrow`.`optics`.`Account` ->
      account.copy(`balance` = value)
    }
  }
)

inline val `arrow`.`optics`.`Account`.Companion.available: arrow.optics.Lens<`arrow`.`optics`.`Account`, `kotlin`.`Int`> inline get()= arrow.optics.Lens(
  get = { account: `arrow`.`optics`.`Account` -> account.`available` },
  set = { value: `kotlin`.`Int` ->
    { account: `arrow`.`optics`.`Account` ->
      account.copy(`available` = value)
    }
  }
)




inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Account`>.balance: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.balance
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Account`>.balance: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.balance
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Account`>.balance: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.balance
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Account`>.balance: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.balance
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Account`>.balance: arrow.optics.Getter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.balance
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Account`>.balance: arrow.optics.Setter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.balance
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Account`>.balance: arrow.optics.Traversal<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.balance
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Account`>.balance: arrow.optics.Fold<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.balance

inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Account`>.available: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.available
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Account`>.available: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.available
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Account`>.available: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.available
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Account`>.available: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.available
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Account`>.available: arrow.optics.Getter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.available
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Account`>.available: arrow.optics.Setter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.available
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Account`>.available: arrow.optics.Traversal<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.available
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Account`>.available: arrow.optics.Fold<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.available

==> arrow-docs-0.8.2-sources.jar: arrow/optics/Account$$optics.kt <==
package `arrow`.`optics`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `arrow`.`optics`.`Account`.Companion.iso: arrow.optics.Iso<`arrow`.`optics`.`Account`, arrow.core.Tuple2<`kotlin`.`Int`, `kotlin`.`Int`>> inline get()= arrow.optics.Iso(
  get = { account: `arrow`.`optics`.`Account` -> arrow.core.Tuple2(account.`balance`, account.`available`) },
  reverseGet = { tuple: arrow.core.Tuple2<`kotlin`.`Int`, `kotlin`.`Int`> -> `arrow`.`optics`.`Account`(tuple.a, tuple.b) }
)

inline val `arrow`.`optics`.`Account`.Companion.balance: arrow.optics.Lens<`arrow`.`optics`.`Account`, `kotlin`.`Int`> inline get()= arrow.optics.Lens(
  get = { account: `arrow`.`optics`.`Account` -> account.`balance` },
  set = { account: `arrow`.`optics`.`Account`, value: `kotlin`.`Int` -> account.copy(`balance` = value) }
)

inline val `arrow`.`optics`.`Account`.Companion.available: arrow.optics.Lens<`arrow`.`optics`.`Account`, `kotlin`.`Int`> inline get()= arrow.optics.Lens(
  get = { account: `arrow`.`optics`.`Account` -> account.`available` },
  set = { account: `arrow`.`optics`.`Account`, value: `kotlin`.`Int` -> account.copy(`available` = value) }
)




inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Account`>.balance: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.balance
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Account`>.balance: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.balance
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Account`>.balance: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.balance
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Account`>.balance: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.balance
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Account`>.balance: arrow.optics.Getter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.balance
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Account`>.balance: arrow.optics.Setter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.balance
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Account`>.balance: arrow.optics.Traversal<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.balance
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Account`>.balance: arrow.optics.Fold<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.balance

inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Account`>.available: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.available
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Account`>.available: arrow.optics.Lens<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.available
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Account`>.available: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.available
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Account`>.available: arrow.optics.Optional<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.available
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Account`>.available: arrow.optics.Getter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.available
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Account`>.available: arrow.optics.Setter<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.available
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Account`>.available: arrow.optics.Traversal<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.available
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Account`>.available: arrow.optics.Fold<S, `kotlin`.`Int`> inline get() = this + `arrow`.`optics`.`Account`.available
